<?php
/**
 * Custom functions that act independently of the theme templates
 *
 * Eventually, some of the functionality here could be replaced by core features
 *
 * @package    Rexus
 * @author     Theme Junkie
 * @copyright  Copyright (c) 2014, Theme Junkie
 * @license    http://www.gnu.org/licenses/gpl-2.0.html
 * @since      1.0.0
 */

/**
 * Get our wp_nav_menu() fallback, wp_page_menu(), to show a home link.
 *
 * @since  1.0.0
 * @param  array $args Configuration arguments.
 * @return array
 */
function rexus_page_menu_args( $args ) {
	$args['show_home'] = true;
	return $args;
}
add_filter( 'wp_page_menu_args', 'rexus_page_menu_args' );

/**
 * Adds custom classes to the array of body classes.
 *
 * @since  1.0.0
 * @param  array $classes Classes for the body element.
 * @return array
 */
function rexus_body_classes( $classes ) {

	// Adds a class of group-blog to blogs with more than 1 published author.
	if ( is_multi_author() ) {
		$classes[] = 'group-blog';
	}

	return $classes;
}
add_filter( 'body_class', 'rexus_body_classes' );

/**
 * Adds custom classes to the array of post classes.
 *
 * @since  1.0.0
 * @param  array $classes Classes for the post element.
 * @return array
 */
function rexus_post_classes( $classes ) {

	// Adds a class if a post hasn't a thumbnail.
	if ( ! has_post_thumbnail() ) {
		$classes[] = 'no-post-thumbnail';
	}

	// Adds clearing class.
	$classes[] = 'clearfix';

	return $classes;
}
add_filter( 'post_class', 'rexus_post_classes' );

/**
 * Filters wp_title to print a neat <title> tag based on what is being viewed.
 *
 * @since  1.0.0
 * @param  string $title Default title text for current view.
 * @param  string $sep Optional separator.
 * @return string The filtered title.
 */
function rexus_wp_title( $title, $sep ) {

	if ( is_feed() ) {
		return $title;
	}
	
	global $page, $paged;

	// Add the blog name
	$title .= get_bloginfo( 'name', 'display' );

	// Add the blog description for the home/front page.
	$site_description = get_bloginfo( 'description', 'display' );
	if ( $site_description && ( is_home() || is_front_page() ) ) {
		$title .= " $sep $site_description";
	}

	// Add a page number if necessary:
	if ( ( $paged >= 2 || $page >= 2 ) && ! is_404() ) {
		$title .= " $sep " . sprintf( __( 'Page %s', 'rexus' ), max( $paged, $page ) );
	}

	return $title;
}
add_filter( 'wp_title', 'rexus_wp_title', 10, 2 );

/**
 * Sets the authordata global when viewing an author archive.
 *
 * This provides backwards compatibility with
 * http://core.trac.wordpress.org/changeset/25574
 *
 * It removes the need to call the_post() and rewind_posts() in an author
 * template to print information about the author.
 *
 * @since  1.0.0
 * @global WP_Query $wp_query WordPress Query object.
 * @return void
 */
function rexus_setup_author() {
	global $wp_query;

	if ( $wp_query->is_author() && isset( $wp_query->post ) ) {
		$GLOBALS['authordata'] = get_userdata( $wp_query->post->post_author );
	}
}
add_action( 'wp', 'rexus_setup_author' );

/**
 * Generates the relevant template info. Adds template meta with theme version. Uses the theme 
 * name and version from style.css.
 *
 * @since 1.0.0
 */
function rexus_meta_template() {
	$theme    = wp_get_theme( get_template() );
	$template = sprintf( '<meta name="template" content="%1$s %2$s" />' . "\n", esc_attr( $theme->get( 'Name' ) ), esc_attr( $theme->get( 'Version' ) ) );

	echo apply_filters( 'rexus_meta_template', $template );
}
add_action( 'wp_head', 'rexus_meta_template', 10 );

/**
 * Removes default styles set by WordPress recent comments widget.
 *
 * @since 1.0.0
 */
function rexus_remove_recent_comments_style() {
	global $wp_widget_factory;
	remove_action( 'wp_head', array( $wp_widget_factory->widgets['WP_Widget_Recent_Comments'], 'recent_comments_style' ) );
}
add_action( 'widgets_init', 'rexus_remove_recent_comments_style' );

/**
 * Change the excerpt more string.
 *
 * @since  1.0.0
 * @param  string  $more
 * @return string
 */
function rexus_excerpt_more( $more ) {
	return '&hellip;';
}
add_filter( 'excerpt_more', 'rexus_excerpt_more' );

/**
 * Control the excerpt length.
 *
 * @since  1.0.0
 * @param  $length
 */
function rexus_excerpt_length( $length ) {
	return 30;
}
add_filter( 'excerpt_length', 'rexus_excerpt_length', 999 );

/**
 * Override the default options.php location.
 *
 * @since  1.0.0
 */
function rexus_location_override() {
	return array( 'admin/options.php' );
}
add_filter( 'options_framework_location', 'rexus_location_override' );

/**
 * Change the theme options text.
 *
 * @since  1.0.0
 * @param  array $menu
 */
function rexus_theme_options_text( $menu ) {
	$menu['page_title'] = '';
	$menu['menu_title'] = __( 'Theme Settings', 'rexus' );

	return $menu;
}
add_filter( 'optionsframework_menu', 'rexus_theme_options_text' );

/**
 * Custom comment form fields.
 *
 * @since  1.0.0
 * @param  array $fields
 * @return array
 */
function rexus_comment_form_fields( $fields ) {

	$commenter = wp_get_current_commenter();
	$req       = get_option( 'require_name_email' );
	$aria_req  = ( $req ? " aria-required='true'" : '' );

	$fields['author'] = '<input class="comment-name" id="author" name="author" type="text" value="' . esc_attr( $commenter['comment_author'] ) . '" size="30" placeholder="' . esc_attr__( 'Name (required)', 'rexus' ) . '"' . $aria_req . ' />';

	$fields['email'] = '<input class="comment-email" id="email" name="email" type="text" value="' . esc_attr(  $commenter['comment_author_email'] ) . '" size="30" placeholder="' . esc_attr__( 'Email (required)', 'rexus' ) . '"' . $aria_req . ' />';

	$fields['url'] = '<input class="comment-website" id="url" name="url" type="text" value="' . esc_attr( $commenter['comment_author_url'] ) . '" size="30" placeholder="' . esc_attr__( 'Website (optional)', 'rexus' ) . '" />';

	return $fields;

}
add_filter( 'comment_form_default_fields', 'rexus_comment_form_fields' );

/**
 * Custom comment form submit field.
 * 
 * @since  1.0.0
 */
function rexus_comment_button() {
	echo '<button type="submit" id="submit">' . __( 'Submit Comment', 'rexus' ) . '</button>';
}
add_action( 'comment_form', 'rexus_comment_button' );

/**
 * Custom RSS feed url.
 *
 * @since  1.0.0
 * @return string
 */
function rexus_feed_url( $output, $feed ) {

	// Get the custom rss feed url.
	$url = of_get_option( 'rexus_feedburner_url' );

	// Do not redirect comments feed
	if ( strpos( $output, 'comments' ) ) {
		return $output;
	}

	// Check the settings.
	if ( !empty( $url ) ) {
		$output = $url;
	}

	return $output;
}
add_filter( 'feed_link', 'rexus_feed_url', 10, 2 );

/**
 * Remove theme-layouts meta box on attachment post type.
 * 
 * @since 1.0.0
 */
function rexus_remove_theme_layout_metabox() {
	remove_post_type_support( 'attachment', 'theme-layouts' );
	remove_post_type_support( 'forum', 'theme-layouts' );
	remove_post_type_support( 'topic', 'theme-layouts' );
	remove_post_type_support( 'reply', 'theme-layouts' );
}
add_action( 'init', 'rexus_remove_theme_layout_metabox', 11 );

/**
 * Modifies the theme layout on several pages.
 *
 * @since  1.0.0
 * @param  string  $layout
 */
function rexus_mod_theme_layout( $layout ) {

	// Layout for bbPress page.
	include_once( ABSPATH . 'wp-admin/includes/plugin.php' );
	if ( is_plugin_active( 'bbpress/bbpress.php' ) ) {

		$setting = of_get_option( 'rexus_bbpress_layout', '1c' );
		$column  = '';

		if ( $setting === '1c' ) {
			$column = '1c';
		} elseif ( $setting === '2c-l' ) {
			$column = '2c-l';
		} else {
			$column = '2c-r';
		}

		if ( is_bbpress() ) {
			$layout = $column;
		}
		
	}

	// Set the layout to 1 column on Teams page.
	if ( is_page_template( 'page-templates/teams.php' ) ) {
		$layout = '1c';
	}

	return $layout;
}
add_filter( 'theme_mod_theme_layout', 'rexus_mod_theme_layout', 15 );

/**
 * Custom style switcher.
 *
 * @since  1.0.0
 */
function rexus_style_switcher() {

	if ( ! of_get_option( 'rexus_switcher', '1' ) ) {
		return;
	}
?>

	<section id="style-switcher">
		<h2><?php _e( 'Style Switcher', 'rexus' ); ?> <a href="#"></a></h2>
		<div>
		<h3><?php _e( 'Predefined Colors', 'rexus' ); ?></h3>
			<ul class="colors" id="color1">
				<li><a href="#" class="blue" title="Blue"></a></li>
				<li><a href="#" class="green" title="Green"></a></li>
				<li><a href="#" class="orange" title="Orange"></a></li>
				<li><a href="#" class="navy" title="Navy"></a></li>
				<li><a href="#" class="yellow" title="Yellow"></a></li>
				<li><a href="#" class="peach" title="Peach"></a></li>
				<li><a href="#" class="beige" title="Beige"></a></li>
				<li><a href="#" class="purple" title="Purple"></a></li>
				<li><a href="#" class="red" title="Red"></a></li>
				<li><a href="#" class="pink" title="Pink"></a></li>
				<li><a href="#" class="celadon" title="Celadon"></a></li>
				<li><a href="#" class="brown" title="Brown"></a></li>
				<li><a href="#" class="cherry" title="Cherry"></a></li>
				<li><a href="#" class="gray" title="Gray"></a></li>
				<li><a href="#" class="deep-blue" title="Deep Blue"></a></li>
				<li><a href="#" class="cyan" title="Cyan"></a></li>
				<li><a href="#" class="olive" title="Olive"></a></li>
				<li><a href="#" class="dirty-green" title="Dirty Green"></a></li>
			</ul>

			<h3><?php _e( 'Background Image', 'rexus' ); ?></h3>
			 <ul class="colors bg" id="bg">
				<li><a href="#" class="bg1"></a></li>
				<li><a href="#" class="bg2"></a></li>
				<li><a href="#" class="bg3"></a></li>
				<li><a href="#" class="bg4"></a></li>
				<li><a href="#" class="bg5"></a></li>
				<li><a href="#" class="bg6"></a></li>
				<li><a href="#" class="bg7"></a></li>
				<li><a href="#" class="bg8"></a></li>
				<li><a href="#" class="bg9"></a></li>
				<li><a href="#" class="bg10"></a></li>
				<li><a href="#" class="bg11"></a></li>
				<li><a href="#" class="bg12"></a></li>
				<li><a href="#" class="bg13"></a></li>
				<li><a href="#" class="bg14"></a></li>
				<li><a href="#" class="bg15"></a></li>
				<li><a href="#" class="bg16"></a></li>
				<li><a href="#" class="bg17"></a></li>
				<li><a href="#" class="bg18"></a></li>
			</ul>
		</div>

		<div id="reset"><a href="#" class="button color blue"><?php _e( 'Reset', 'rexus' ); ?></a></div>

	</section>

<?php
}
add_action( 'wp_footer', 'rexus_style_switcher', 20 );